"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var inquirer = require("inquirer");
var _ = require("lodash");
var log_1 = require("../util/log");
var login_1 = require("../util/login");
var multichoice_1 = require("../util/multichoice");
module.exports = function (program) {
    program
        .command("remove")
        .option("--instance <value>", "Name of instance to remove")
        .option("-a, --all", "remove all instances")
        .description("remove a instance from the login list")
        .action(function (options) {
        var previousLogins = login_1.Login.getPreviousLogins();
        var mayNotBeAuthenticated = true;
        var prompts = [];
        if (!options["instance"]) {
            if (previousLogins.length > 0) {
                if (options["all"]) {
                    prompts.push((0, multichoice_1.default)({
                        type: "list",
                        choices: ["Yes", "No"],
                        message: "Are you sure you'd like to delete all instances?",
                        name: "removeAll",
                    }));
                }
                else {
                    prompts.push((0, multichoice_1.default)({
                        type: "list",
                        choices: function () {
                            var options = _.map(previousLogins, "instance");
                            return options;
                        },
                        message: "Select the instance you desire to remove ",
                        name: "instance",
                    }), (0, multichoice_1.default)({
                        type: "list",
                        choices: ["Yes", "No"],
                        message: "Are you sure you'd like to remove this instance?",
                        name: "removeInstance",
                        when: function (answers) {
                            // only ask if an instance was selected
                            return !!answers.instance;
                        },
                    }));
                }
            }
            else {
                log_1.log.fail("There are no prior logins on this computer. Use domo login to log an instance before using this command");
                process.exit();
            }
            inquirer.prompt(prompts).then(function (answers) {
                if (answers["removeAll"] === "Yes") {
                    login_1.Login.removeAllLogins();
                    log_1.log.ok("All instances have been removed");
                }
                else if (answers["removeInstance"] == "Yes") {
                    login_1.Login.removeLogin(answers.instance);
                    log_1.log.ok("Instance removed successfully.");
                }
                else
                    log_1.log.ok("You have chosen not to remove any instances");
            });
        }
    });
};
//# sourceMappingURL=remove.js.map