"use strict";
/**
 * domo dev server
 */
Object.defineProperty(exports, "__esModule", { value: true });
var path = require("path");
var _ = require("lodash");
var fs = require("fs-extra");
var bs = require("browser-sync").create();
var portfinder = require("portfinder");
portfinder.basePort = 3000;
var session_1 = require("../util/session");
var appStructure = require("../util/appStructure");
var manifest_1 = require("../util/manifest");
var log_1 = require("../util/log");
var express = require("express");
var app = express();
var Proxy = require("@domoinc/ryuu-proxy").Proxy;
var domoOptions;
var manifest = manifest_1.Manifest.get();
var domoApp;
var assetsPort;
var dataPort;
module.exports = {
    start: function (domo, options) {
        return new Promise(function (resolve, reject) {
            portfinder.getPorts(2, {}, function (err, ports) {
                return new Promise(function (resolve, reject) {
                    assetsPort = ports[0];
                    dataPort = ports[1];
                    domoApp = domo;
                    domoOptions = options;
                    if (manifest["proxyId"] === undefined)
                        return resolve(domoApp.createApp(manifest.id).then(function (app) { return app.instance.id; }));
                    else
                        return resolve("");
                })
                    .then(function (test) {
                    if (test !== "")
                        manifest.proxyId = test;
                    var proxy = new Proxy({ manifest: manifest });
                    app.use("/domodev", express.static(path.resolve(__dirname + "/../server/domodev")));
                    app.use(express.static("."));
                    app.use(proxy.express());
                    session_1.Session.check(domoApp)
                        .then(function () {
                        var external = Boolean(domoOptions.external);
                        app.listen(dataPort);
                        bs.init({
                            proxy: "localhost:" + dataPort,
                            port: assetsPort,
                            notify: false,
                            ui: false,
                            logLevel: "info",
                            logPrefix: "Domo Dev",
                            online: external,
                            // TODO: add user's ignored files here too?
                            files: ["**/*", "!node_modules/**/*"],
                        });
                        bs.instance.logger.info("Instance: " + domoApp.getInstance());
                    })
                        .catch(function (e) {
                        log_1.log.notAuthenticated;
                    });
                });
            });
        });
    },
};
app.get("/", function (req, res) {
    domoApp.getDomoappsURL(manifest)
        .then(function (appData) {
        // sizes consistent with Domo Web
        var sizeMultiplier = {
            width: 235,
            height: 290,
        };
        var width = sizeMultiplier.width * manifest.size.width - 10 + "px";
        var height = sizeMultiplier.height * manifest.size.height - 40 + "px";
        var userId = domoOptions.userId || appData.user.id;
        var customerId = 1 || appData.customer;
        var url = "index.html?userId=".concat(userId, "&customer=").concat(customerId, "&locale=en-US&platform=desktop");
        var hasThumbnail = appStructure.hasThumbnail();
        var template = _.template(fs.readFileSync(path.resolve(__dirname + "/../server/domodev/index.html"), "utf8"));
        var fullpage = manifest.fullpage;
        res.send(template({
            manifest: manifest,
            width: width,
            height: height,
            url: url,
            hasThumbnail: hasThumbnail,
            fullpage: fullpage,
        }));
    });
});
//# sourceMappingURL=server.js.map