"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.log = void 0;
var chalk = require("chalk");
var log = /** @class */ (function () {
    function log() {
    }
    /**
     * log a success
     */
    log.ok = function (msg, submessage) {
        console.log(chalk.green('\u2713'), msg);
        if (submessage) {
            console.log(chalk.gray(submessage));
        }
    };
    /**
     * log info
     */
    log.info = function (msg, submessage) {
        console.log(chalk.cyan(msg));
        if (submessage) {
            console.log(chalk.gray(submessage));
        }
    };
    /**
     * log warning
     */
    log.warn = function (msg, submessage) {
        console.log(chalk.yellow(msg));
        if (submessage) {
            console.log(chalk.gray(submessage));
        }
    };
    /**
     * log an error and exit node
     */
    log.fail = function (msg, submessage, result) {
        console.log(chalk.red('X'), msg);
        if (submessage) {
            console.log(chalk.gray(submessage));
        }
        if (result && result.message) {
            console.log(chalk.gray(result.message));
        }
        if (process.argv.indexOf('verbose') !== -1) {
            console.log(chalk.red('statusCode:'), result.statusCode);
            console.log(chalk.red('method:'), result.method);
            console.log(chalk.red('path:'), result.url);
            console.log(chalk.red('failureMessage:'), result.failureMessage);
        }
        process.exit(1);
    };
    log.notAuthenticated = function (refreshToken) {
        if (!refreshToken) {
            log.fail('Failure to authenticate', 'Mising refresh token, please login using "domo login"');
        }
        else if (refreshToken) {
            log.fail('Not authenticated', 'Your refresh token may have been revoked. Please login again with "domo login".');
        }
        else {
            log.fail('Not authenticated');
        }
    };
    // ERR SHOULD BE AN ERROR?
    log.clientRequestFailed = function (err, failureMessage) {
        var message = 'You are not authenticated or your refresh token may have been revoked. Please login again with "domo login"';
        if (failureMessage) {
            message = failureMessage;
        }
        log.fail(err, message);
    };
    log.handleErrorMessage = function (err, label) {
        label = label || 'Error sending request';
        //const toe = err && err.res && err.res.body;
        return label; //+ toe
    };
    return log;
}());
exports.log = log;
//# sourceMappingURL=log.js.map