"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Login = void 0;
var glob = require("glob");
var fs = require("fs-extra");
var path = require("path");
var models_1 = require("../models");
var Domo = require("ryuu-client");
var log_1 = require("./log");
var Configstore = require("configstore");
var inquirer = require("inquirer");
var home = Domo.getHomeDir();
var Login = /** @class */ (function () {
    function Login() {
    }
    Login.getMostRecent = function () {
        var logins = glob.sync(home + "/ryuu/*.json");
        //If there are no logins, return a rejection as the user is unauthenticated.
        if (logins.length === 0) {
            //@ts-ignore
            return Promise.resolve({});
        }
        var recent = logins.reduce(function (prev, next) {
            return fs.statSync(prev).mtime > fs.statSync(next).mtime ? prev : next;
        });
        var loginData = fs.readJsonSync(recent);
        return Promise.resolve(loginData.instance);
    };
    Login.getMostRecentLogin = function (mayNotBeAuthenticated) {
        var _this = this;
        return this.getMostRecent().then(function (instance) {
            return _this.getLogin(instance);
        });
    };
    Login.getPreviousLogins = function () {
        var logins = (glob.sync(home + "/ryuu/*.json") || []).map(function (file) {
            return fs.readJsonSync(file);
        });
        return logins;
    };
    /**
     * persist login to user's domo home
     */
    Login.persistLogin = function (instance, refreshToken, devToken) {
        var configstore = new Configstore("/ryuu/" + instance);
        configstore.set("instance", instance);
        configstore.set("refreshToken", refreshToken);
        configstore.set("devToken", !!devToken);
        return { instance: instance, refreshToken: refreshToken, devToken: devToken };
    };
    Login.removeDevToken = function (instance) {
        var configstore = new Configstore("/ryuu/" + instance);
        deleteRefreshToken(instance);
        configstore.set("devToken", false);
    };
    Login.removeLogin = function (instance) {
        var loginFile = path.resolve(home + "/ryuu/" + instance + ".json");
        fs.ensureFileSync(loginFile);
        return fs.unlink(loginFile);
    };
    Login.removeAllLogins = function () {
        fs.emptyDirSync(home + "/ryuu/");
    };
    Login.verifyLogin = function (login) {
        verifyLoginLocal(login);
    };
    Login.logout = function (login) {
        var instance = login.getInstance();
        deleteRefreshToken(instance);
        var configstore = new Configstore("/ryuu/" + instance);
        if (!configstore.get("refreshToken")) {
            log_1.log.ok("Successful logout from " + instance);
            return Promise.resolve(true);
        }
        log_1.log.fail("Failed logout from ".concat(instance));
        return Promise.resolve(false);
    };
    Login.getLogin = function (instance) {
        var configstore = new Configstore("/ryuu/" + instance);
        var proxy = new Configstore("/proxy");
        var username = proxy.get("username");
        if (username) {
            return inquirer
                .prompt([
                {
                    type: "password",
                    message: "Please enter your password:",
                    name: "pass",
                },
            ])
                .then(function (answers) {
                return Promise.resolve(new Domo(instance, configstore.get("refreshToken"), models_1.constant.CLIENT_ID, {
                    host: proxy.get("host"),
                    port: proxy.get("port"),
                    //@ts-ignore
                    username: proxy.get("username"),
                    password: answers.pass,
                }, configstore.get("devToken")));
            });
        }
        else {
            try {
                return Promise.resolve(new Domo(instance, configstore.get("refreshToken"), models_1.constant.CLIENT_ID, { host: proxy.get("host"), port: proxy.get("port") }, configstore.get("devToken")));
            }
            catch (ex) {
                return Promise.resolve(new Domo(instance, configstore.get("refreshToken"), models_1.constant.CLIENT_ID));
            }
        }
    };
    return Login;
}());
exports.Login = Login;
function verifyLoginLocal(login) {
    if (!login.refreshToken)
        log_1.log.fail("Not authenticated", 'Please login using "domo login"');
}
function deleteRefreshToken(instance) {
    var configstore = new Configstore("/ryuu/" + instance);
    configstore.all = {
        instance: configstore.get("instance"),
        devToken: false,
    };
}
//# sourceMappingURL=login.js.map